@@ -20,6 +20,8 @@
 
 #include "kig_part.h"
 
+#include <kigpart_export.h>
+
 #include "aboutdata.h"
 #include "kig_commands.h"
 #include "kig_document.h"
@@ -44,43 +46,29 @@
 #include <functional>
 #include <iterator>
 
-#include <QAction>
-#include <QFileDialog>
-#include <QStandardPaths>
 #include <QDirIterator>
-#include <QDebug>
+#include <QFileDialog>
+#include <QFile>
+#include <QMimeType>
+#include <QMimeDatabase>
+#include <QPrintDialog>
+#include <QPrinter>
+#include <QPrintPreviewDialog>
+#include <QStandardPaths>
+#include <QTimer>
 
 #include <KAboutData>
-
-#include <kdemacros.h>
-#include <kiconloader.h>
-#include <kcomponentdata.h>
-#include <kxmlguiwindow.h>
-#include <kactioncollection.h>
-#include <kmessagebox.h>
-#include <kmimetype.h>
-#include <kstandardaction.h>
-#include <ktoggleaction.h>
-#include <ktogglefullscreenaction.h>
-#include <kundostack.h>
-#include <kdeprintdialog.h>
-#include <kprintpreview.h>
-#include <KPluginFactory>
+#include <KActionCollection>
+#include <KIconLoader>
 #include <KIconEngine>
+#include <KMessageBox>
+#include <KUndoActions>
+#include <KPluginFactory>
+#include <KStandardAction>
+#include <KToggleAction>
 
 #include <KParts/OpenUrlArguments>
 
-#include <qbytearray.h>
-#include <qcheckbox.h>
-#include <qeventloop.h>
-#include <qfile.h>
-#include <qlayout.h>
-#include <qsizepolicy.h>
-#include <qtimer.h>
-#include <QIcon>
-#include <QPrinter>
-#include <QPrintDialog>
-
 using namespace std;
 
 static const QString typesFile = "macros.kigt";
@@ -222,9 +210,9 @@ KigPart::KigPart( QWidget *parentWidget, QObject *parent,
   setupTypes();
 
   // construct our command history
-  mhistory = new KUndoStack();
-  mhistory->createUndoAction( actionCollection() );
-  mhistory->createRedoAction( actionCollection() );
+  mhistory = new QUndoStack();
+  KUndoActions::createUndoAction( mhistory, actionCollection() );
+  KUndoActions::createRedoAction( mhistory, actionCollection() );
   connect( mhistory, SIGNAL( cleanChanged( bool ) ), this, SLOT( setHistoryClean( bool ) ) );
 
   // we are read-write by default
@@ -425,14 +413,15 @@ bool KigPart::openFile()
     return false;
   };
 
-  KMimeType::Ptr mimeType = KMimeType::mimeType( arguments().mimeType() );
-  if ( !mimeType )
+  const QMimeDatabase mimeDb;
+  QMimeType mimeType = mimeDb.mimeTypeForName( arguments().mimeType() );
+  if ( !mimeType.isValid() )
   {
     // we can always use findByPath instead of findByURL with localFilePath()
-    mimeType = KMimeType::findByPath( localFilePath() );
+    mimeType = mimeDb.mimeTypeForFile( localFilePath() );
   }
-  qDebug() << "mimetype: " << mimeType->name();
-  KigFilter* filter = KigFilters::instance()->find( mimeType->name() );
+  qDebug() << "mimetype: " << mimeType.name();
+  KigFilter* filter = KigFilters::instance()->find( mimeType.name() );
   if ( !filter )
   {
     // we don't support this mime type...
@@ -440,7 +429,7 @@ bool KigPart::openFile()
       (
         widget(),
         i18n( "You tried to open a document of type \"%1\"; unfortunately, Kig does not support this format. If you think the format in question would be worth implementing support for, you can open a feature request in <a href=\"https://bugs.kde.org/enter_bug.cgi?product=kig&bug_severity=wishlist\">KDE's bug tracking system</a>"
-          , mimeType->name()),
+          , mimeType.name()),
         i18n( "Format Not Supported" ),
         KMessageBox::Notify | KMessageBox::AllowLink
         );
@@ -478,8 +467,9 @@ bool KigPart::saveFile()
 {
   if ( url().isEmpty() ) return internalSaveAs();
   // mimetype:
-  KMimeType::Ptr mimeType = KMimeType::findByPath ( localFilePath() );
-  if ( mimeType->name() != "application/x-kig" )
+  const QMimeDatabase mimeDb;
+  const QMimeType mimeType = mimeDb.mimeTypeForFile( localFilePath() );
+  if ( mimeType.name() != "application/x-kig" )
   {
     // we don't support this mime type...
     if( KMessageBox::warningYesNo( widget(),
@@ -892,7 +882,7 @@ void KigPart::delWidget( KigWidget* v )
 void KigPart::filePrintPreview()
 {
   QPrinter printer;
-  KPrintPreview printPreview( &printer );
+  QPrintPreviewDialog printPreview( &printer );
   doPrint( printer, document().grid(), document().axes() );
   printPreview.exec();
 }
@@ -901,18 +891,18 @@ void KigPart::filePrint()
 {
   QPrinter printer;
   KigPrintDialogPage* kp = new KigPrintDialogPage();
-  QPrintDialog *printDialog = KdePrint::createPrintDialog( &printer, QList<QWidget*>() << kp, m_widget );
-  printDialog->setWindowTitle( i18n("Print Geometry") );
+  QPrintDialog printDialog( &printer, m_widget );
+  printDialog.setWindowTitle( i18n("Print Geometry") );
+  printDialog.setOptionTabs( { kp } );
   printer.setFullPage( true );
   //Unsupported in Qt
   //printer.setPageSelection( QPrinter::ApplicationSide );
   kp->setPrintShowGrid( document().grid() );
   kp->setPrintShowAxes( document().axes() );
-  if (printDialog->exec())
+  if (printDialog.exec())
   {
     doPrint( printer, kp->printShowGrid(), kp->printShowAxes() );
   }
-  delete printDialog;
 }
 
 void KigPart::doPrint( QPrinter& printer, bool printGrid, bool printAxes )
@@ -1019,7 +1009,7 @@ KigDocument& KigPart::document()
   return *mdocument;
 }
 
-extern "C" KDE_EXPORT int convertToNative( const QUrl &url, const QByteArray& outfile )
+extern "C" KIGPART_EXPORT int convertToNative( const QUrl &url, const QByteArray& outfile )
 {
   qDebug() << "converting " << url.toDisplayString( QUrl::PrettyDecoded ) << " to " << outfile;
 
@@ -1039,9 +1029,10 @@ extern "C" KDE_EXPORT int convertToNative( const QUrl &url, const QByteArray& ou
     return -1;
   };
 
-  KMimeType::Ptr mimeType = KMimeType::findByPath ( file );
-  qDebug() << "mimetype: " << mimeType->name();
-  KigFilter* filter = KigFilters::instance()->find( mimeType->name() );
+  const QMimeDatabase mimeDb;
+  const QMimeType mimeType = mimeDb.mimeTypeForFile( file );
+  qDebug() << "mimetype: " << mimeType.name();
+  KigFilter* filter = KigFilters::instance()->find( mimeType.name() );
   if ( !filter )
   {
     qCritical() << "The file \"" << file << "\" is of a filetype not currently supported by Kig." << endl;
