@@ -45,7 +45,7 @@ public:
    * dimension (both in radians).
    */
   AngleImp( const Coordinate& pt, double start_angle_in_radials,
-            double angle_in_radials );
+            double angle_in_radials, bool markRightAngle );
   ~AngleImp();
 
   ObjectImp* transform( const Transformation& ) const;
@@ -86,6 +86,10 @@ public:
    */
   double angle() const { return mangle; }
 
+  bool markRightAngle() const { return mmarkRightAngle; }
+
+  void setMarkRightAngle( bool markRightAngle ) { mmarkRightAngle = markRightAngle; }
+
   bool equals( const ObjectImp& rhs ) const;
 };
 
